/*

Coobird's Blocks - Block breaking Java game.

Copyright (c) 2008, Chris Kroells
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the author nor the names of its contributors may be
      used to endorse or promote products derived from this software without
      specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/


package net.coobird.blocks;

import java.awt.*;
import java.awt.event.*;
import java.io.File;

/**
 * Runs Coobird's Blocks as a Java application.
 * @author coobird
 *
 */
public class BlocksApp
{
	private BlocksPanel b;
	
	/**
	 * Default constructor for <code>BlocksApp</code>.
	 * This constructor calls the <code>BlocksApp(String[])</code> constructor
	 * with the argument of <code>null</code>. 
	 */
	public BlocksApp()
	{
		this(null);		
	}
	
	/**
	 * Instantiates <code>BlocksApp</code>, the Coobird's Blocks application.
	 * This class acts as an application wrapper for <code>BlocksPanel</code>
	 * which displays and performs the game related processing along with
	 * <code>BlocksEngine</code> game engine.
	 * @param args Command-line arguments.
	 */
	public BlocksApp(String[] args)
	{
		// Sets the default path to the background image.
		String backgroundImagePath = 
			System.getProperty("user.dir") + File.separator + "background.jpg";
		
		// Process command-line arguments.
		if (args != null)
		{
			int length = args.length;
			
			for (int i = 0; i < length; i++)
			{
				if (i + 1 < length)
					if (args[i].equals("-background"))
						backgroundImagePath = args[i+1];
			}
		}
		
		// Instantiate the BlocksPanel.
		b = new BlocksPanel();
		
		Frame f = new Frame("Coobird's Blocks");
		f.setLayout(new BorderLayout());
		f.add(b, BorderLayout.CENTER);
		f.setVisible(true);
		f.setSize(f.getInsets().left + f.getInsets().right + b.getPreferredSize().width,
					f.getInsets().top + f.getInsets().bottom + b.getPreferredSize().height);
		f.validate();
		
		f.addWindowListener(new BlocksWindowManager());
		
		b.setBackgroundImage(backgroundImagePath);
		b.init();
		
		try
		{
			Thread.sleep(100);
		}
		catch (Exception e) {}
		b.repaint();
	}

	/**
	 * Main method for the Blocks application.
	 * @param args Command-line arguments. There are no command-line
	 * arguments at this point.
	 */
	public static void main(String[] args)
	{
		new BlocksApp(args);
	}

	/**
	 * A WindowAdapter subclass to handle window close events.
	 * @author coobird
	 *
	 */
	class BlocksWindowManager extends WindowAdapter
	{
		public void windowClosed(WindowEvent e)
		{
			System.exit(0);
		}
		
		public void windowClosing(WindowEvent e)
		{
			b.stop();
			System.exit(0);
		}
	}
}
