/*

Coobird's Blocks - Block breaking Java game.

Copyright (c) 2008, Chris Kroells
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the author nor the names of its contributors may be
      used to endorse or promote products derived from this software without
      specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/


package net.coobird.blocks;

import java.applet.Applet;
import java.io.IOException;
import java.net.*;

/**
 * Runs Coobird's Blocks as a Java applet.
 * @author coobird
 *
 */
public class BlocksApplet extends Applet
{
	private static final long serialVersionUID = -6915975208388550882L;

	private BlocksPanel bp;
	
	/**
	 * Initializes the applet.
	 */
	public void init()
	{
		bp = new BlocksPanel(); 		
		this.add(bp);
	}
	
	/**
	 * Starts the game engine and applet.
	 */
	public void start()
	{
		bp.init();
		
		// Gets the background image filename parameter.
		String bgImage = this.getParameter("background");
		
		try
		{
			URL codebase = this.getCodeBase();
			URL backgroundURL = new URL(codebase, bgImage);
			
			// Test to see the URL has a valid resource.
			// Can't find a better way to find out if there's an image
			// at the specified URL.
			backgroundURL.getContent();
			
			bp.setBackgroundImage(this.getImage(backgroundURL));
		}
		catch (MalformedURLException e)
		{
			e.printStackTrace(System.out);
		}
		catch (IOException e)
		{
			e.printStackTrace(System.out);

			bp.setBackgroundImage((java.awt.Image)null);
		}

		bp.repaint();
	}
	
	/**
	 * Stops the game engine and applet.
	 */
	public void stop()
	{
		bp.stop();
	}
	
	/**
	 * Repaints the contents of the applet.
	 */
	public void repaint()
	{
		bp.repaint();
	}
}
